@@ -33,10 +33,12 @@ class GeneratorConfigTests(TestCase):
             '    <Format repr="true" eq="true" order="false" unsafeHash="false" frozen="false" slots="false" kwOnly="false">dataclasses</Format>\n'
             "    <Structure>filenames</Structure>\n"
             "    <DocstringStyle>reStructuredText</DocstringStyle>\n"
+            "    <FilterStrategy>allGlobals</FilterStrategy>\n"
             "    <RelativeImports>false</RelativeImports>\n"
             '    <CompoundFields defaultName="choice" forceDefaultName="false">false</CompoundFields>\n'
             "    <PostponedAnnotations>false</PostponedAnnotations>\n"
             "    <UnnestClasses>false</UnnestClasses>\n"
+            "    <IgnorePatterns>false</IgnorePatterns>\n"
             "  </Output>\n"
             "  <Conventions>\n"
             '    <ClassName case="pascalCase" safePrefix="type"/>\n'
@@ -49,6 +51,7 @@ class GeneratorConfigTests(TestCase):
             '    <Substitution type="package" search="http://www.w3.org/2001/XMLSchema" replace="xs"/>\n'
             '    <Substitution type="package" search="http://www.w3.org/XML/1998/namespace" replace="xml"/>\n'
             '    <Substitution type="package" search="http://www.w3.org/2001/XMLSchema-instance" replace="xsi"/>\n'
+            '    <Substitution type="package" search="http://www.w3.org/1998/Math/MathML" replace="mathml3"/>\n'
             '    <Substitution type="package" search="http://www.w3.org/1999/xlink" replace="xlink"/>\n'
             '    <Substitution type="package" search="http://www.w3.org/1999/xhtml" replace="xhtml"/>\n'
             '    <Substitution type="package" search="http://schemas.xmlsoap.org/wsdl/soap/" replace="soap"/>\n'
@@ -90,10 +93,12 @@ class GeneratorConfigTests(TestCase):
             ' frozen="false" slots="false" kwOnly="false">dataclasses</Format>\n'
             "    <Structure>filenames</Structure>\n"
             "    <DocstringStyle>reStructuredText</DocstringStyle>\n"
+            "    <FilterStrategy>allGlobals</FilterStrategy>\n"
             "    <RelativeImports>false</RelativeImports>\n"
             '    <CompoundFields defaultName="choice" forceDefaultName="false">false</CompoundFields>\n'
             "    <PostponedAnnotations>false</PostponedAnnotations>\n"
             "    <UnnestClasses>false</UnnestClasses>\n"
+            "    <IgnorePatterns>false</IgnorePatterns>\n"
             "  </Output>\n"
             "  <Conventions>\n"
             '    <ClassName case="pascalCase" safePrefix="type"/>\n'
@@ -123,7 +128,6 @@ class GeneratorConfigTests(TestCase):
             GeneratorConfig.read(file_path)
 
     def test_format_with_invalid_state(self):
-
         with self.assertRaises(GeneratorConfigError) as cm:
             OutputFormat(eq=False, order=True)
 
