@@ -1,5 +1,11 @@
+from xsdata.formats.dataclass.serializers.code import PycodeSerializer
 from xsdata.formats.dataclass.serializers.json import DictFactory
 from xsdata.formats.dataclass.serializers.json import JsonSerializer
 from xsdata.formats.dataclass.serializers.xml import XmlSerializer
 
-__all__ = ["JsonSerializer", "DictFactory", "XmlSerializer"]
+__all__ = [
+    "DictFactory",
+    "JsonSerializer",
+    "XmlSerializer",
+    "PycodeSerializer",
+]
