@@ -134,6 +134,21 @@ class DocstringStyle(Enum):
     BLANK = "Blank"
 
 
+class ClassFilterStrategy(Enum):
+    """
+    Class filter strategy.
+
+    :cvar ALL: all: Generate all types, discouraged!!!
+    :cvar ALL_GLOBALS: allGlobals: Generate all global types
+    :cvar REFERRED_GLOBALS: referredGlobals: Generate all global types
+        with at least one reference.
+    """
+
+    ALL = "all"
+    ALL_GLOBALS = "allGlobals"
+    REFERRED_GLOBALS = "referredGlobals"
+
+
 class ObjectType(Enum):
     """
     Object type enumeration.
@@ -223,12 +238,14 @@ class GeneratorOutput:
     :param format: Output format
     :param structure_style: Output structure style, default: filenames
     :param docstring_style: Docstring style, default: reStructuredText
+    :param filter_strategy: Class filter strategy, default: globals
     :param relative_imports: Use relative imports, default: false
     :param compound_fields: Use compound fields for repeatable elements, default: false
     :param max_line_length: Adjust the maximum line length, default: 79
     :param postponed_annotations: Enable postponed evaluation of annotations,
         default: false, python>=3.7 Only
     :param unnest_classes: Move inner classes to upper level, default: false
+    :param ignore_patterns: Ignore pattern restrictions, default: false
     """
 
     package: str = element(default="generated")
@@ -237,22 +254,15 @@ class GeneratorOutput:
         default=StructureStyle.FILENAMES, name="Structure"
     )
     docstring_style: DocstringStyle = element(default=DocstringStyle.RST)
+    filter_strategy: ClassFilterStrategy = element(
+        default=ClassFilterStrategy.ALL_GLOBALS
+    )
     relative_imports: bool = element(default=False)
     compound_fields: CompoundFields = element(default_factory=CompoundFields)
     max_line_length: int = attribute(default=79)
     postponed_annotations: bool = element(default=False)
     unnest_classes: bool = element(default=False)
-
-    def __post_init__(self):
-        self.validate()
-
-    def validate(self):
-        if self.postponed_annotations and sys.version_info < (3, 7):
-            self.postponed_annotations = False
-            warnings.warn(
-                "postponed annotations requires python >= 3.7, reverting...",
-                CodeGenerationWarning,
-            )
+    ignore_patterns: bool = element(default=False)
 
     def update(self, **kwargs: Any):
         objects.update(self, **kwargs)
