@@ -12,7 +12,7 @@ def load_entry_points(name: str):
     if hasattr(entry_points, "select"):
         plugins = entry_points.select(group=name)  # type: ignore
     else:
-        plugins = entry_points.get(name, [])
+        plugins = entry_points.get(name, [])  # type: ignore
 
     for plugin in plugins:
         plugin.load()
